@@ -29,7 +29,7 @@ pub use {
     interface_role::*,
     module_id::*,
     role::*,
-    strings::{CiString, CsString},
+    strings::{CiString, CsString, StringError},
     version::*,
     version_details::*,
     version_number::*,
